# Coerce

[![Build Status](https://travis-ci.org/almcc/coerce.svg?branch=master)](https://travis-ci.org/almcc/coerce)
[![Coverage Status](https://coveralls.io/repos/github/almcc/coerce/badge.svg?branch=master)](https://coveralls.io/github/almcc/coerce?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
